unit loglib;

{----------------------------------------------------}
{        TLogger component for Delphi                }
{ Version: 1.01                                      }
{ Created: 2003.08.23                                }
{ Updated: 2004.02.04                                }
{ E-mail:  monster@Noniewicz.com                     }
{ WWW:     http://www.Noniewicz.com                  }
{ Legal:   (c)2003-2004 MoNsTeR/GDC, Jakub Noniewicz }
{ Licence: FREEWARE                                  }
{----------------------------------------------------}
{ History:                                           }
{ Version 1.00, last update: 2003.08.23              }
{ Version 1.01, last update: 2004.02.04              }
{----------------------------------------------------}
{                 LEGAL NOTICE:                      }
{ This software is provided 'as-is', without any     }
{ express or implied warranty. In no event will      }
{ the author be held liable for any damages arising  }
{ from the use of this software.                     }                                                   
{ Permission is granted to anyone to use this        }
{ software for any purpose, including commercial     }
{ applications, and to alter it and redistribute it  }
{ freely, subject to the following restrictions:     }                                     
{ 1. The origin of this software must not            }
{    be misrepresented, you must not claim that you  }
{    wrote the original software.                    }
{    If you use this software in a product,          }
{    an acknowledgment in the product documentation  }
{    would be appreciated but is not required.       }                                            
{ 2. Altered source versions must be plainly marked  }
{    as such, and must not be misrepresented as      }
{    being the original software.                    }                                                
{ 3. This notice may not be removed or altered from  }
{    any source distribution.                        }
{----------------------------------------------------}



interface

uses Windows, classes, SysUtils;


type
  TLogger = class(TComponent)
  private
    LogFile: TextFile;
    FFileName: string;
    FUseDate: boolean;
    FUseTime: boolean;
    FDateFormat: String;
    FTimeFormat: String;
    FOnOpenFail: TNotifyEvent;
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    function OpenLog: boolean;
    function WriteLog(msg: string): boolean;
    procedure CloseLog;
  published
    property FileName: String read FFileName write FFileName;
    property UseDate: boolean read FUseDate write FUseDate;
    property UseTime: boolean read FUseTime write FUseTime;
    property DateFormat: String read FDateFormat write FDateFormat;
    property TimeFormat: String read FTimeFormat write FTimeFormat;
    property OnOpenFail: TNotifyEvent read FOnOpenFail write FOnOpenFail;
  end;


procedure Register;

implementation


{$R *.DCR}

procedure Register;
begin
  RegisterComponents('Monster', [TLogger]);
end;


function TLogger.OpenLog: boolean;
var OpenLog1: boolean;
begin
  OpenLog1 := true;
  try
    AssignFile(LogFile, FileName);
    Append(LogFile);
  except
    try
      Rewrite(LogFile);
    except
      OpenLog1 := false;
      if assigned(FOnOpenFail) then FOnOpenFail(self);
    end;
  end;
  Result := OpenLog1;
end; { OpenLog }

function TLogger.WriteLog(msg: string): boolean;
var WriteLog1: boolean;
    fmt: string;
begin
  WriteLog1 := true;
  try
    fmt := '';
    if FUseDate then
      fmt := FDateFormat;
    if FUseTime then
      fmt := fmt + ' ' + FTimeFormat;
    Write(LogFile, '['+FormatDateTime(fmt, Now)+'] ');
    WriteLn(LogFile, msg);
    Flush(LogFile);
  except
    WriteLog1 := false;
  end;
  Result := WriteLog1;
end; { WriteLog }

procedure TLogger.CloseLog;
begin
  try
    CloseFile(LogFile);
  except
  end;
end; { CloseLog }

constructor TLogger.Create(AOwner: TComponent);
begin
  inherited;
  FOnOpenFail := nil;
  FFileName := '';
  FUseDate := true;
  FUseTime := true;
  FDateFormat := 'yyyy-mm-dd';
  FTimeFormat := 'hh:nn:ss';
end; { Create }

destructor TLogger.Destroy;
begin
  inherited;
end; { Destroy }

end.
